const {sqlHandle} = require("../config/db")
const {isValue, paramToUnder} = require("../../util/index")
const PageResult = require("../config/page")
const ParamsEntity = require("../entity/params-entity")
const ParamsService = {
  list: ({sourceId, name, orderByColumn, isAsc}) => {
    return new Promise(async (resolve, reject) => {
      try {
        let sql = 'SELECT * FROM ship_test_params'
        let where = ['del_flag = 0']
        if (isValue(sourceId)) {
          where.push(`source_id = "${sourceId}"`)
        } else {
          return reject('数据源ID不可为空')
        }
        if (isValue(name)) {
          where.push(`name LIKE "%${name}%"`)
        }
        if (where.length > 0) {
          sql += ' ' + `WHERE ${where.join(' AND ')}`
        }
        if (isValue(orderByColumn)) {
          sql += ' ' + `ORDER BY ${paramToUnder(orderByColumn)} ${isAsc ? 'ASC' : 'DESC'}`
        } else {
          sql += ' ' + `ORDER BY sort DESC`
        }
        const result = await sqlHandle(sql)
        return resolve(result.map(v => new ParamsEntity(v)))
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  page: ({sourceId, pageNum, pageSize, name, orderByColumn, isAsc}) => {
    return new Promise(async (resolve, reject) => {
      try {
        let sql = 'SELECT * FROM ship_test_params'
        let where = ['del_flag = 0']
        if (isValue(sourceId)) {
          where.push(`source_id = "${sourceId}"`)
        } else {
          return reject('数据源ID不可为空')
        }
        if (isValue(name)) {
          where.push(`name LIKE "%${name}%"`)
        }
        if (where.length > 0) {
          sql += ' ' + `WHERE ${where.join(' AND ')}`
        }
        if (isValue(orderByColumn)) {
          sql += ' ' + `ORDER BY ${paramToUnder(orderByColumn)} ${isAsc ? 'ASC' : 'DESC'}`
        } else {
          sql += ' ' + `ORDER BY sort DESC`
        }
        const result = await PageResult(sql, pageNum, pageSize, ParamsEntity)
        return resolve(result)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  info: (id) => {
    return new Promise(async (resolve, reject) => {
      try {
        let sql = 'SELECT * FROM ship_test_params'
        let where = ['del_flag = 0']
        if (!isValue(id)) {
          return reject('id不可为空')
        } else {
          where.push(`id = ${id}`)
        }
        if (where.length > 0) {
          sql += ' ' + `WHERE ${where.join(' AND ')}`
        }
        const result = await sqlHandle(sql)
        return resolve(result.map(v => new ParamsEntity(v))?.[0])
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  queryBy: ({name}) => {
    return new Promise(async (resolve, reject) => {
      try {
        let sql = 'SELECT * FROM ship_test_params'
        let where = ['del_flag = 0']
        if (isValue(name)) {
          where.push(`name = "${name}"`)
        }
        if (where.length > 0) {
          sql += ' ' + `WHERE ${where.join(' AND ')}`
        }
        const result = await sqlHandle(sql)
        return resolve(result.map(v => new ParamsEntity(v)))
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  add: (form) => {
    return new Promise(async (resolve, reject) => {
      try {
        const paramsEntity = new ParamsEntity(form)
        const values = [
          ['source_id', paramsEntity.sourceId],
          ['name', paramsEntity.name],
          ['remark', paramsEntity.remark],
          ['sort', paramsEntity.sort],
          ['default_cql', paramsEntity.defaultCql],
        ]
        const sql = `INSERT INTO ship_test_params (${values.map(v => v[0]).join(',')}) VALUES (${values.map(v => '?').join(',')})`
        if (!isValue(paramsEntity.sourceId)) {
          return reject('数据源ID不可为空')
        }
        const sameValid = await ParamsService.queryBy({name: paramsEntity.name})
        if (sameValid.length > 0) {
          return reject('已存在相同名称!')
        }
        const result = await sqlHandle(sql, values.map(v => v[1]))
        return resolve(result.insertId)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  edit: (form) => {
    return new Promise(async (resolve, reject) => {
      try {
        const paramsEntity = new ParamsEntity(form)
        const values = [
          ['name', paramsEntity.name],
          ['remark', paramsEntity.remark],
          ['sort', paramsEntity.sort],
          ['default_cql', paramsEntity.defaultCql],
        ]
        let sql = `UPDATE ship_test_params SET ${values.map(v => `${v[0]} = ?`).join(',')}`
        if (!isValue(paramsEntity.id)) {
          return reject('id不可为空!')
        } else {
          sql += ' ' + `WHERE id = "${paramsEntity.id}"`
        }
        const sameValid = await ParamsService.queryBy({name: paramsEntity.name})
        if (sameValid.filter(v => v.id !== paramsEntity.id).length > 0) {
          return reject('已存在相同名称!')
        }
        const result = await sqlHandle(sql, values.map(v => v[1]))
        return resolve(paramsEntity.id)
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  },
  del: (ids) => {
    return new Promise(async (resolve, reject) => {
      try {
        let sql = 'UPDATE ship_test_params SET del_flag = "1"'
        if (ids?.length === 0) {
          return reject('ids不可为空!')
        } else {
          sql += ' ' + 'WHERE id IN (?)'
        }
        const result = await sqlHandle(sql, [ids])
        return resolve('删除成功!')
      } catch (e) {
        return reject(e.sqlMessage)
      }
    })
  }
}
module.exports = ParamsService